Use Case:  Browse community news
================================

Actor
-----

  - Site Visitor

Overview
--------

  Visitors to a CMF Site will typically return to the site after
  an initial visit only if the site's content was interesting or
  valuable to them.  They will return often to the site only if
  they perceive that this interesting and valuable content is
  being frequently updated.  This use case deals with the most
  common "dynamic" feature of a CMF Site:  its list of published
  News Items.

Procedure
---------

  1.  Select the 'news' link from the navigation bar.  The system
      will display the ten most recent News Items, sorted in
      descending date order.  If there are more than ten
      published News Items, the system will display a link to
      the next batch at the bottom of the page.

  2.  Navigate between batches of News Items by clicking the
      "10 older artcles" and "10 newer articles" links.
